@@ -7,7 +7,7 @@ use strict;
 use 5.012;
 
 
-our $VERSION = 'v0.0.10';
+our $VERSION = 'v0.0.11';
 
 # Load the dependencies so we'll be sure they are installed.
 use Carp;
@@ -30,6 +30,7 @@ use Storable;
 use String::ShellQuote;
 use Task::Test::Run::AllPlugins;
 use Template;
+use Test::Code::TidyAll;
 use Test::Data::Split;
 use Test::Differences;
 use Test::More;
@@ -55,7 +56,7 @@ Freecell Solver test suite.
 
 =head1 VERSION
 
-version v0.0.10
+version v0.0.11
 
 =head1 SYNOPSIS
 
@@ -63,13 +64,13 @@ version v0.0.10
 
 =head1 VERSION
 
-version v0.0.10
+version v0.0.11
 
 =head1 TASK CONTENTS
 
 =head1 VERSION
 
-version v0.0.10
+version v0.0.11
 
 =head1 AUTHOR
 
@@ -90,7 +91,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/shlomif/fc-solve/issues
+L<https://github.com/shlomif/fc-solve/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -226,7 +227,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/shlomif/fc-solve/issues
+L<https://github.com/shlomif/fc-solve/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
